==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE82S.sql <==
/****************************************************************************/
/* GE82 ( DB定義書管理テーブル )                                            */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GE82 (
   SYSTEM_ID    VARCHAR  (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR  (    1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , KBTBL        VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /*  30 ﾃｰﾌﾞﾙ区分    */
 , TABLE_NAME   VARCHAR  (   50 )                   NOT NULL            /*  40 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      VARCHAR  (  200 )                                       /*  50 名称         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  60 表示順       */
 , CLM_NAME     VARCHAR  (  120 )                                       /*  70 項目名(漢字) */
 , CLM          VARCHAR  (   30 )                   NOT NULL            /*  80 項目         */
 , CLS_NAME     VARCHAR  (   10 )                   NOT NULL            /*  90 DBｸﾗｽ        */
 , VIEW_LENGTH  VARCHAR  (   10 )                                       /* 100 表示桁数     */
 , USE_LENGTH   VARCHAR  (    9 )                                       /* 110 使用桁数     */
 , UK           VARCHAR  (    2 )                                       /* 120 ﾕﾆｰｸｷｰ       */
 , LUK          VARCHAR  (    2 )                                       /* 130 論理ﾕﾆｰｸｷｰ   */
 , IXA          VARCHAR  (    2 )                                       /* 140 ｲﾝﾃﾞｯｸｽA     */
 , IXB          VARCHAR  (    2 )                                       /* 150 ｲﾝﾃﾞｯｸｽB     */
 , IXC          VARCHAR  (    2 )                                       /* 160 ｲﾝﾃﾞｯｸｽC     */
 , IXD          VARCHAR  (    2 )                                       /* 170 ｲﾝﾃﾞｯｸｽD     */
 , IXE          VARCHAR  (    2 )                                       /* 180 ｲﾝﾃﾞｯｸｽE     */
 , IXF          VARCHAR  (    2 )                                       /* 190 ｲﾝﾃﾞｯｸｽF     */
 , IXG          VARCHAR  (    2 )                                       /* 200 ｲﾝﾃﾞｯｸｽG     */
 , IXH          VARCHAR  (    2 )                                       /* 210 ｲﾝﾃﾞｯｸｽH     */
 , IXI          VARCHAR  (    2 )                                       /* 220 ｲﾝﾃﾞｯｸｽI     */
 , IXJ          VARCHAR  (    2 )                                       /* 230 ｲﾝﾃﾞｯｸｽJ     */
 , IXK          VARCHAR  (    2 )                                       /* 240 ｲﾝﾃﾞｯｸｽK     */
 , NOT_NULL     VARCHAR  (    1 )                                       /* 250 ﾉｯﾄﾇﾙ        */
 , RENDERER     VARCHAR  (   10 )                                       /* 260 表示種別     */
 , EDITOR       VARCHAR  (   10 )                                       /* 270 編集種別     */
 , DBTYPE       VARCHAR  (   10 )                                       /* 280 文字種別     */
 , DATA_DEFAULT VARCHAR  (  200 )                                       /* 290 初期値       */
 , KBCLM        VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 300 ｶﾗﾑ区分      */
 , BIKO         VARCHAR  ( 2000 )                                       /* 310 備考         */
 , CDKH         VARCHAR  (    1 )                                       /* 320 改廃ｺｰﾄﾞ     */
 , COMMENTS     VARCHAR  (  500 )                                       /* 330 ｺﾒﾝﾄ         */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR  (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR  (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR  (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR  (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR  (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR  (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR  (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR  (   10 )                                       /* 890 更新者       */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GE82S.sql <==
/****************************************************************************/
/* GE82 ( DB定義書管理テーブル )                                            */
/*                                                                          */
/* Created : 2020/12/16 08:13:57                                            */
/****************************************************************************/

CREATE TABLE GE82 (
   SYSTEM_ID    VARCHAR  (   10 )                   NOT NULL            /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR  (    1 )                   NOT NULL            /*  20 ﾃｰﾌﾞﾙ種別    */
 , KBTBL        VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /*  30 ﾃｰﾌﾞﾙ区分    */
 , TABLE_NAME   VARCHAR  (   50 )                   NOT NULL            /*  40 ﾃｰﾌﾞﾙ名      */
 , NAME_JA      VARCHAR  (  200 )                                       /*  50 名称         */
 , SEQNO        INTEGER                 DEFAULT 0   NOT NULL            /*  60 表示順       */
 , CLM_NAME     VARCHAR  (  120 )                                       /*  70 項目名(漢字) */
 , CLM          VARCHAR  (   30 )                   NOT NULL            /*  80 項目         */
 , CLS_NAME     VARCHAR  (   10 )                   NOT NULL            /*  90 DBｸﾗｽ        */
 , VIEW_LENGTH  VARCHAR  (   10 )                                       /* 100 表示桁数     */
 , USE_LENGTH   VARCHAR  (    9 )                                       /* 110 使用桁数     */
 , UK           VARCHAR  (    2 )                                       /* 120 ﾕﾆｰｸｷｰ       */
 , LUK          VARCHAR  (    2 )                                       /* 130 論理ﾕﾆｰｸｷｰ   */
 , IXA          VARCHAR  (    2 )                                       /* 140 ｲﾝﾃﾞｯｸｽA     */
 , IXB          VARCHAR  (    2 )                                       /* 150 ｲﾝﾃﾞｯｸｽB     */
 , IXC          VARCHAR  (    2 )                                       /* 160 ｲﾝﾃﾞｯｸｽC     */
 , IXD          VARCHAR  (    2 )                                       /* 170 ｲﾝﾃﾞｯｸｽD     */
 , IXE          VARCHAR  (    2 )                                       /* 180 ｲﾝﾃﾞｯｸｽE     */
 , IXF          VARCHAR  (    2 )                                       /* 190 ｲﾝﾃﾞｯｸｽF     */
 , IXG          VARCHAR  (    2 )                                       /* 200 ｲﾝﾃﾞｯｸｽG     */
 , IXH          VARCHAR  (    2 )                                       /* 210 ｲﾝﾃﾞｯｸｽH     */
 , IXI          VARCHAR  (    2 )                                       /* 220 ｲﾝﾃﾞｯｸｽI     */
 , IXJ          VARCHAR  (    2 )                                       /* 230 ｲﾝﾃﾞｯｸｽJ     */
 , IXK          VARCHAR  (    2 )                                       /* 240 ｲﾝﾃﾞｯｸｽK     */
 , NOT_NULL     VARCHAR  (    1 )                                       /* 250 ﾉｯﾄﾇﾙ        */
 , RENDERER     VARCHAR  (   10 )                                       /* 260 表示種別     */
 , EDITOR       VARCHAR  (   10 )                                       /* 270 編集種別     */
 , DBTYPE       VARCHAR  (   10 )                                       /* 280 文字種別     */
 , DATA_DEFAULT VARCHAR  (  200 )                                       /* 290 初期値       */
 , KBCLM        VARCHAR  (    1 )       DEFAULT '0' NOT NULL            /* 300 ｶﾗﾑ区分      */
 , BIKO         VARCHAR  ( 2000 )                                       /* 310 備考         */
 , CDKH         VARCHAR  (    1 )                                       /* 320 改廃ｺｰﾄﾞ     */
 , COMMENTS     VARCHAR  (  500 )                                       /* 330 ｺﾒﾝﾄ         */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR  (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR  (   14 )                                       /* 820 作成日時     */
 , PGSET        VARCHAR  (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR  (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR  (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR  (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR  (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR  (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR  (   10 )                                       /* 890 更新者       */
);
